#
# PySNMP MIB module T11-FC-ZONE-SERVER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-ZONE-SERVER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:30:47 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion")
( FcDomainIdOrZero, fcmInstanceIndex, fcmSwitchIndex, FcNameIdOrZero, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "FcDomainIdOrZero", "fcmInstanceIndex", "fcmSwitchIndex", "FcNameIdOrZero")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( Bits, TimeTicks, IpAddress, Integer32, ModuleIdentity, Counter64, NotificationType, iso, ObjectIdentity, MibIdentifier, mib_2, Counter32, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "TimeTicks", "IpAddress", "Integer32", "ModuleIdentity", "Counter64", "NotificationType", "iso", "ObjectIdentity", "MibIdentifier", "mib-2", "Counter32", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32")
( StorageType, TruthValue, TextualConvention, TimeStamp, DisplayString, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "TruthValue", "TextualConvention", "TimeStamp", "DisplayString", "RowStatus")
( t11FamLocalSwitchWwn, ) = mibBuilder.importSymbols("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamLocalSwitchWwn")
( T11NsGs4RejectReasonCode, ) = mibBuilder.importSymbols("T11-FC-NAME-SERVER-MIB", "T11NsGs4RejectReasonCode")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11ZoneServerMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 160)).setRevisions(("2007-06-27 00:00",))
if mibBuilder.loadTexts: t11ZoneServerMIB.setLastUpdated('200706270000Z')
if mibBuilder.loadTexts: t11ZoneServerMIB.setOrganization("For the initial versions, T11.\n                   For later versions, the IETF's IMSS Working Group.")
if mibBuilder.loadTexts: t11ZoneServerMIB.setContactInfo('     Claudio DeSanti\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  EMail: cds@cisco.com\n\n                  Keith McCloghrie\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  EMail: kzm@cisco.com')
if mibBuilder.loadTexts: t11ZoneServerMIB.setDescription("The MIB module for the management of Fibre Channel Zoning\n           Servers, both for Basic Zoning Management and for Enhanced\n\n\n           Zoning Management, as defined in the FC-GS-5 specification.\n\n           FC-GS-5 defines (in-band) management operations for\n           manipulating the Zone Set Database, some for use in Basic\n           mode (e.g., 'Add Zone Set (AZS)', etc.), and some for use in\n           Enhanced mode (e.g., Create Zone Set (CZS)', etc.).  When\n           Enhanced Zoning Management is in use, FC-GS-5 requires that\n           these in-band management operations be rejected unless they\n           are issued within the context of a GS-5 server session.  The\n           use of a server session ensures serialized access to the\n           Zoning Database since the Fabric lock for the Zone Server\n           must be obtained as a part of establishing the server\n           session to the Zone Server.\n\n           Thus, if and when this MIB is used for Enhanced Zoning\n           Management, SNMP SetRequests that request the modification\n           of zoning definitions must be serialized with respect to\n           the GS-5 requests to modify the Zoning Database.  This is\n           achieved by requiring that an SNMP management application\n           must first obtain the Fabric lock for the Zone Server\n           before attempting to modify any zoning definitions.  The\n           companion T11-FC-FABRIC-LOCK-MIB module is defined as a means\n           of obtaining the Fabric lock for the Zone Server (or any\n           other server).\n\n           In Enhanced Zoning Management, a Zone Server keeps track of\n           changes requested in the zoning definitions, but does not\n           update its Zone Set Database unless there is (and until\n           there is) a 'commit' operation.  To model this behavior,\n           this MIB module assumes that a Zone Server (in Enhanced\n           mode) takes a snapshot of its Zone Set Database as and when\n           the Fabric lock (for the Zone Server application) is\n           obtained; this snapshot is used to create what is herein\n           called the 'copy' database.  It is this 'copy' database\n           that is then updated by SNMP SetRequests (while the Fabric\n           is locked).  If and when a 'commit' operation is requested\n           (while the Fabric is still locked), the 'copy' database is\n           then used to overwrite the previously committed contents of\n           the Zone Set Database, and the new Zone Set Database is\n           distributed to all other switches in the Fabric.  When the\n           lock is released, any changes made that were not\n           'committed' are discarded.\n\n           When this MIB is used for Basic Zoning Management, the same\n           set of MIB objects as used for Enhanced mode are used to\n           make changes to the Database of a Zone Server on a\n           particular switch, but the changes take immediate effect at\n           that switch without an explicit commit.  The distribution of\n\n\n\n           those changes to Zone Servers on other switches in the\n           Fabric is subsequently requested through the use of a\n           separate set of MIB objects.\n\n           The management information specified in this MIB module\n           includes the Zoning Database for each of one or more Fibre\n           Channel Fabrics.  A Zoning Database is a combination of the\n           Fabric's Zone Set Database and its Active Zone Set.  The\n           Active Zone Set is the Zone Set currently enforced by the\n           Fabric; a Zone Set Database is a database of the Zone Sets\n           available to be activated within a Fabric.  All the MIB\n           objects representing a Zone Set Database are modifiable at\n           any time (irrespective of the value of any RowStatus\n           object), whereas all objects representing the Active Zone\n           Set are always read-only (except to deactivate it and/or\n           activate a different one).\n\n           Copyright (C) The IETF Trust (2007).  This version\n           of this MIB module is part of RFC 4936;  see the RFC\n           itself for full legal notices.")
t11ZsMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 160, 1))
t11ZsMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 160, 2))
t11ZsMIBNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 160, 0))
t11ZsConfiguration = MibIdentifier((1, 3, 6, 1, 2, 1, 160, 1, 1))
t11ZsStatistics = MibIdentifier((1, 3, 6, 1, 2, 1, 160, 1, 2))
class T11ZsZoneMemberType(Unsigned32, TextualConvention):
    displayHint = 'x'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,255)

class T11ZsRejectReasonExplanation(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,))
    namedValues = NamedValues(("other", 1), ("noAdditionalExplanation", 2), ("zonesNotSupported", 3), ("zoneSetNameUnknown", 4), ("noZoneSetActive", 5), ("zoneNameUnknown", 6), ("zoneStateUnknown", 7), ("incorrectPayloadLen", 8), ("tooLargeZoneSet", 9), ("deactivateZoneSetFailed", 10), ("reqNotSupported", 11), ("capabilityNotSupported", 12), ("zoneMemberIDTypeNotSupp", 13), ("invalidZoneSetDefinition", 14), ("enhancedZoningCmdsNotSupported", 15), ("zoneSetExists", 16), ("zoneExists", 17), ("aliasExists", 18), ("zoneSetUnknown", 19), ("zoneUnknown", 20), ("aliasUnknown", 21), ("zoneAliasTypeUnknown", 22), ("unableEnhancedMode", 23), ("basicZoningCmdsNotSupported", 24), ("zoneAttribObjectExists", 25), ("zoneAttribObjectUnknown", 26), ("requestInProcess", 27), ("cmitInProcess", 28), ("hardEnforcementFailed", 29), ("unresolvedReferences", 30), ("consistencyChecksFailed", 31),)

class T11ZoningName(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,64)

t11ZsServerTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 1), )
if mibBuilder.loadTexts: t11ZsServerTable.setDescription('A table containing information about the Zone Servers\n           on each Fabric in one or more switches, and providing\n           the capability to perform operations on their Zone\n           Server databases.')
t11ZsServerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"))
if mibBuilder.loadTexts: t11ZsServerEntry.setDescription('Each entry contains information specific to a\n           Zone Server for a particular Fabric (identified by\n           the value of t11ZsServerFabricIndex) on a particular\n           switch (identified by values of fcmInstanceIndex\n           and fcmSwitchIndex).\n\n           The persistence across reboots of writable values in\n           a row of this table is given by the instance of\n           t11ZsServerDatabaseStorageType in that row.')
t11ZsServerFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11ZsServerFabricIndex.setDescription('A unique index value that uniquely identifies a\n           particular Fabric.')
t11ZsServerCapabilityObject = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 2), Bits().clone(namedValues=NamedValues(("enhancedMode", 0), ("zoneSetDb", 1), ("activateDirect", 2), ("hardZoning", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerCapabilityObject.setDescription("This bitmap represents the capability of the switch\n           on this Fabric:\n\n               'enhancedMode' - able to support enhanced Zoning\n                                mode of operation.\n\n               'zoneSetDb'    - able to support maintaining of\n                                a Zone Set Database.\n\n               'activateDirect' - able to support the Activate\n                                  Direct command.\n\n               'hardZoning'   - able to support Hard Zoning.")
t11ZsServerDatabaseStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 3), StorageType().clone('nonVolatile')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerDatabaseStorageType.setDescription("This object specifies the memory realization, on a\n           particular switch, of the Zone Set database for a\n           particular Fabric.  Specifically, each row in the\n           following tables:\n\n                      t11ZsSetTable\n                      t11ZsZoneTable\n                      t11ZsSetZoneTable\n                      t11ZsAliasTable\n                      t11ZsZoneMemberTable\n                      t11ZsAttribBlockTable\n                      t11ZsAttribTable\n\n           has a StorageType as specified by the instance of\n           this object that is INDEXed by the same values of\n           fcmInstanceIndex, fcmSwitchIndex, and\n\n\n           t11ZsServerFabricIndex.\n\n           The value of this object is also used to indicate\n           the persistence across reboots of writable values in\n           its row of the t11ZsServerTable, as well as the\n           corresponding row in the t11ZsNotifyControlTable.\n\n           If an instance of this object has the value\n           'permanent(4)', the Zone Set database for the given\n           Fabric on the given switch is not required to be\n           writeable.")
t11ZsServerDistribute = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("noop", 1), ("zoneSetDb", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerDistribute.setDescription("This object can be set only in Basic mode.  When set\n           to the value 'zoneSetDb', it requests that the Zone Set\n           database of a particular switch for a particular Fabric\n           be distributed to every other switch in that Fabric,\n           e.g., by using Stage Fabric Configuration Update (SFC)\n           and Update Fabric Configuration (UFC) requests.\n\n           Setting this object to 'noop' has no effect.\n           When read, the value of this object is always 'noop'.\n\n           When the corresponding instance of t11ZsServerOperationMode\n           has the value 'enhanced', or when the corresponding instance\n           of t11ZsZoneSetResult has the value 'inProgress', it\n           is inconsistent to try to set the value of this object.")
t11ZsServerCommit = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("commitZoneChanges", 1), ("noop", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerCommit.setDescription("This object is only used in Enhanced mode.\n\n            In Enhanced mode, it can only be modified when the Fabric\n            lock for the Zone Server on the particular Fabric has been\n            obtained for use by SNMP SetRequests, and even then, only\n            by the SNMP entity identified by the value of corresponding\n            instance of t11FLockInitiator.\n\n            Setting the object requests an action:\n\n              commitZoneChanges - requests that the changes made\n                                  within this session to the Zone\n                                  Set Database be committed.\n              noop              - requests nothing.\n\n            When read, the value is always 'noop'.")
t11ZsServerResult = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("none", 1), ("inProgress", 2), ("success", 3), ("rejectFailure", 4), ("otherFailure", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerResult.setDescription("In Basic mode, this object indicates the status/result\n           of the last distribution of the Zone Set database that\n           was invoked via the corresponding instance of\n           t11ZsZoneSetDistribute, e.g., the status/result of\n           Stage Fabric Configuration Update (SFC) request(s) used\n           to implement the setting of t11ZsZoneSetDistribute.\n\n           In Enhanced mode, this object indicates the status/result\n           of the last commit of changes to the Zone Set database\n           that was invoked via the corresponding instance of\n           t11ZsServerCommit.\n\n             'none'          - no distribution/commit invoked\n                               via the corresponding instance of\n                               t11ZsZoneSetDistribute (Basic mode)\n\n\n                               or t11ZsServerCommit (Enhanced mode).\n             'inProgress'    - distribution/commit is still in\n                               progress.\n             'success'       - distribution/commit completed\n                               successfully.\n             'rejectFailure' - distribution/commit failed due to\n                               an SW_RJT.\n             'otherFailure'  - distribution/commit failed for some\n                               other reason.\n\n           When the value is 'rejectFailure', the corresponding\n           instances of t11ZsServerReasonCode,\n           t11ZsServerReasonCodeExp and t11ZsServerReasonVendorCode\n           contain the reason codes. ")
t11ZsServerReasonCode = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 7), T11NsGs4RejectReasonCode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerReasonCode.setDescription("When the corresponding instance of t11ZsZoneSetResult\n           has the value 'rejectFailure', this object contains\n           the rejection's reason code.\n\n           When the corresponding instance of t11ZsServerResult\n           has a value other than 'rejectFailure', this object\n           should contain the value 'none'.")
t11ZsServerReasonCodeExp = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 8), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(1,1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerReasonCodeExp.setDescription("When the corresponding instance of t11ZsZoneSetResult\n           has the value 'rejectFailure', this object contains\n           the rejection's reason code explanation.\n\n           When the corresponding instance of t11ZsServerResult\n           has a value other than 'rejectFailure', this object\n\n\n\n           should contain the zero-length string.")
t11ZsServerReasonVendorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 9), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(1,1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerReasonVendorCode.setDescription("When the corresponding instance of t11ZsZoneSetResult\n           has the value 'rejectFailure', this object contains\n           the rejection's reason vendor-specific code.\n\n           When the corresponding instance of t11ZsServerResult\n           has a value other than 'rejectFailure', this object\n           should contain the zero-length string.")
t11ZsServerLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerLastChange.setDescription('The value of sysUpTime at the time of the last change\n           (creation, modification, or deletion) to the Zone Set\n           database for the Zone Server for a particular Fabric.\n           If said Zone Set database has not changed since the\n           last re-initialization of the local network management\n           system, then this object will contain a zero value.')
t11ZsServerHardZoning = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 11), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerHardZoning.setDescription('This object indicates whether this switch, if and when it\n           is in Basic mode, enforces Hard Zoning on this Fabric.')
t11ZsServerReadFromDatabase = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("committedDB", 1), ("copyDB", 2),)).clone('committedDB')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerReadFromDatabase.setDescription("In Enhanced mode, this object specifies whether\n           subsequent SNMP Responses (generated by the local SNMP\n           agent) to operations that read the configuration of\n           Zone Sets, Zones, Members, Aliases and Attributes will\n           reflect the values stored in the current (committed)\n           Zone Set database, or those stored in the 'copy'\n           database.\n\n           In Basic mode, the value of this object is always\n           'committedDB' (since there is no 'copy' database in\n           Basic mode).  In SNMP agents that don't support\n           write access to the Zone Set database, this object\n           is always 'committedDB' (since the copy database,\n           if it were to exist, would be identical).")
t11ZsServerOperationMode = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("basic", 1), ("enhanced", 2),)).clone('basic')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerOperationMode.setDescription("The operational mode of the Zone Server.\n\n           Setting this object to 'enhanced' is a request that the mode\n           of operation of the Zone Server be Enhanced mode, which is\n           only possible if all devices in the Fibre Channel Fabric are\n           capable of working in Enhanced mode.  If not, the request\n           will fail and the corresponding value of\n           t11ZsServerChangeModeResult will so indicate.\n\n           Setting this object to 'basic' is a request that the mode\n           of operation of the Zone Server be Basic mode.  However,\n           such a set may fail while operating in Enhanced mode,\n           since FC-GS-5 makes no provision for changing (back)\n\n\n\n           to Basic mode.\n\n           Note that setting this object does not cause or require\n           that the Fabric lock for the Zone Server be obtained.\n           However, when this object has the value 'enhanced', any SNMP\n           SetRequests that attempt to modify the copy database cannot\n           be successful if the Fabric lock has not been obtained\n           or has since been released.")
t11ZsServerChangeModeResult = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("success", 1), ("failure", 2), ("inProgress", 3), ("none", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsServerChangeModeResult.setDescription("When this object has the value of 'success' or\n           'failure', the value indicates the outcome of the most\n           recent request, invoked via t11ZsServerOperationMode,\n           to change the mode of operation of the Zone Server.\n           When such a request is in progress, this object has the\n           value 'inProgress'.  Prior to the first such request,\n           the value of this object is 'none'.")
t11ZsServerDefaultZoneSetting = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 15), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("permit", 1), ("deny", 2),)).clone('deny')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerDefaultZoneSetting.setDescription("This object controls the Enhanced Zoning flag that\n           governs the behavior of the Default Zone on this Fabric.\n\n           If this object is set to 'permit', then the members of\n           the Default Zone on this Fabric can communicate with\n           each other.\n\n\n\n\n           If this object is set to 'deny', then the members of the\n           Default Zone on this Fabric cannot communicate with each\n           other.")
t11ZsServerMergeControlSetting = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("allow", 1), ("restrict", 2),)).clone('allow')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerMergeControlSetting.setDescription("This object controls the Enhanced Zoning flag that\n           indicates the Merge Control Setting for this Fabric:\n\n               'allow'    - a switch may join the Fabric only if\n                            its Zoning Database is able to merge\n                            with the Fabric's Zoning Database.\n               'restrict' - a switch may join the Fabric only if\n                            its Zoning Database is equal to the\n                            Fabric's Zoning Database.")
t11ZsServerDefZoneBroadcast = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 1, 1, 17), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsServerDefZoneBroadcast.setDescription("This object controls an Enhanced Zoning capability:\n           it indicates whether Broadcast Zoning is enabled on\n           the Default Zone on this Fabric.  If this object is\n           set to 'true', then it is enabled.  If this object is\n           set to 'false', then it is disabled.\n\n           If broadcast Zoning is enabled on a Default Zone,\n           then broadcast frames generated by a member in that\n           Default Zone will be restricted to members in that\n           Default Zone.")
t11ZsSetTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 2), )
if mibBuilder.loadTexts: t11ZsSetTable.setDescription("A table containing information on every Zone\n           Set in the Zone Set database of the Zone Servers\n           on each Fabric in one or more switches.\n\n           In Enhanced mode, changes to a database made via this\n           table are always made to the 'copy' database, but\n           values read from this table reflect the contents of\n           either the 'copy' database or the current (committed)\n           database as indicated by the corresponding value of\n           t11ZsServerReadFromDatabase.")
t11ZsSetEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 2, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsSetIndex"))
if mibBuilder.loadTexts: t11ZsSetEntry.setDescription('Each entry contains information about a Zone Set\n           in the Zone Set database of a particular Fabric\n           (identified by the value of t11ZsServerFabricIndex)\n           on a particular switch (identified by values of\n           fcmInstanceIndex and fcmSwitchIndex).\n\n           A Zone Set can be created in an existing Zone Set\n           database, and can contain zero or more existing\n           Zones.  As and when new Zones are created\n           (as rows in the t11ZsZoneTable), they can be added\n           to a Zone Set by creating an entry for each in the\n           t11ZsSetZoneTable.  Deleting a row from this table\n           deletes the Zone Set from the Zone Set database\n           maintained by the Zone Server, but does not otherwise\n           affect the Zone Server.\n\n           The StorageType of a row in this table is specified by\n           the instance of t11ZsServerDatabaseStorageType that is\n\n\n\n           INDEXed by the same values of fcmInstanceIndex,\n           fcmSwitchIndex, and t11ZsServerFabricIndex.')
t11ZsSetIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsSetIndex.setDescription('The index of a Zone Set.  This object uniquely\n           identifies a Zone Set in the Zone Set database\n           for a particular Fabric on a particular switch.')
t11ZsSetName = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 2, 1, 2), T11ZoningName()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsSetName.setDescription('The name of this Zone Set.  The t11ZsSetName should\n           be unique within a Fabric.\n\n           The Zone Set can be renamed at any time (i.e., even\n           when the row in an active state) by setting this object\n           to a new value.')
t11ZsSetRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 2, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsSetRowStatus.setDescription("The status of this conceptual row.\n\n           This object cannot be set to 'active' unless the\n           corresponding value of t11ZsSetName is unique within\n           the Fabric's Zone Server database on this switch.")
t11ZsZoneTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 3), )
if mibBuilder.loadTexts: t11ZsZoneTable.setDescription("This table gives information on all the Zones in the\n           Zone Set database of the Zone Servers on each Fabric\n           in one or more switches.\n\n           In Enhanced mode, changes to a database made via this\n           table are always made to the 'copy' database, but\n           values read from this table reflect the contents of\n           either the 'copy' database or the current (committed)\n           database as indicated by the corresponding value of\n           t11ZsServerReadFromDatabase.")
t11ZsZoneEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 3, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsZoneIndex"))
if mibBuilder.loadTexts: t11ZsZoneEntry.setDescription('Each entry contains information about a Zone\n           in the Zone Set database of a particular Fabric\n           (identified by the value of t11ZsServerFabricIndex)\n           on a particular switch (identified by values of\n           fcmInstanceIndex and fcmSwitchIndex).\n\n           A Zone can be created in an existing Zone Set\n           database, by first creating an entry in this table,\n           and then adding members to it by creating entries in the\n           t11ZsZoneMemberTable.\n\n           The StorageType of a row in this table is specified by\n           the instance of t11ZsServerDatabaseStorageType that is\n           INDEXed by the same values of fcmInstanceIndex,\n           fcmSwitchIndex, and t11ZsServerFabricIndex.')
t11ZsZoneIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsZoneIndex.setDescription("An index value that uniquely identifies this\n           Zone within a particular Fabric's Zone Set database\n           on a particular switch.")
t11ZsZoneName = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 3, 1, 2), T11ZoningName()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsZoneName.setDescription('The name of this Zone.  The t11ZsZoneName should be\n           unique within a Fabric.\n\n           The Zone can be renamed by setting this object\n           to a new value.')
t11ZsZoneAttribBlock = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 3, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsZoneAttribBlock.setDescription('This object specifies the index value of the\n           Zone Attribute Block that contains the Attributes\n           of this Zone.\n\n           In Enhanced mode, a value of zero indicates this\n           Zone has no Zone Attributes.  In Basic mode, this\n           object always has the value of zero.')
t11ZsZoneRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 3, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsZoneRowStatus.setDescription("The status of this conceptual row.\n\n           This object cannot be set to 'active' unless the\n\n\n\n           corresponding value of t11ZsZoneName is unique within\n           the Fabric's Zone Server database on this switch.")
t11ZsSetZoneTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 4), )
if mibBuilder.loadTexts: t11ZsSetZoneTable.setDescription('This table specifies which Zones belong to which Zone\n           Sets in the Zone Set database of the Zone Servers\n           on each Fabric in one or more switches.')
t11ZsSetZoneEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 4, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsSetIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsZoneIndex"))
if mibBuilder.loadTexts: t11ZsSetZoneEntry.setDescription("Each entry specifies that a particular Zone (identified\n           by the value of t11ZsZoneIndex) is one of the Zones\n           that form a particular Zone Set (identified by the\n           value of t11ZsSetIndex) in the Zone Set database of a\n           particular Fabric (identified by the value of\n           t11ZsServerFabricIndex) on a particular switch\n           (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).\n\n           When a row in this table exists, it references one row in\n           the t11ZsSetTable and one row in the t11ZsZoneTable.  The\n           agent must ensure that both such rows when referenced by an\n           active row in this table, do exist and have a status of\n           'active', either by refusing to create new rows in this\n           table, or by automatically deleting rows in this table.\n\n           An 'active' row in this table references one row in the\n           t11ZsSetTable and one in the t11ZsZoneTable.  The agent must\n           ensure that all such referenced rows exist with a status of\n           'active', either by refusing to create new active rows in\n           this table, or by automatically deleting any rows in this\n           table that reference a deleted row.\n\n           The StorageType of a row in this table is specified by\n           the instance of t11ZsServerDatabaseStorageType that is\n\n\n\n           INDEXed by the same values of fcmInstanceIndex,\n           fcmSwitchIndex, and t11ZsServerFabricIndex.")
t11ZsSetZoneRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 4, 1, 1), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsSetZoneRowStatus.setDescription('The status of this conceptual row.')
t11ZsAliasTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 5), )
if mibBuilder.loadTexts: t11ZsAliasTable.setDescription("This table contains information about the Zone Aliases\n           in the Zone Set database of the Zone Servers on each\n           Fabric in one or more switches.\n\n           In Enhanced mode, changes to a database made via this\n           table are always made to the 'copy' database, but\n           values read from this table reflect the contents of\n           either the 'copy' database or the current (committed)\n           database as indicated by the corresponding value of\n           t11ZsServerReadFromDatabase.")
t11ZsAliasEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 5, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsAliasIndex"))
if mibBuilder.loadTexts: t11ZsAliasEntry.setDescription("Each entry contains information about a Zone Alias in\n           the Zone Set database of a particular Fabric\n           (identified by the value of t11ZsServerFabricIndex) on\n\n\n\n           a particular switch (identified by values of\n           fcmInstanceIndex and fcmSwitchIndex).\n\n           A Zone Member is added to a Zone Alias by creating\n           an entry in the t11ZsZoneMemberTable pointing to a\n           row of this table via t11ZsAliasIndex, i.e.,:\n\n            - t11ZsZoneMemberParentType = 'alias',\n            - t11ZsZoneMemberParentIndex = Alias's t11ZsAliasIndex,\n            - t11ZsZoneMemberFormat != '05 - Alias Name', and\n            - t11ZsZoneMemberID = Member's identifier.\n\n           A Zone Alias is added to a Zone by creating\n           an entry in the t11ZsZoneMemberTable pointing to a\n           row of this table via t11ZsAliasName, i.e.,:\n\n            - t11ZsZoneMemberParentType = 'zone',  and\n            - t11ZsZoneMemberParentIndex = Zone's t11ZsZoneIndex,\n            - t11ZsZoneMemberFormat = '05 - Alias Name',\n            - t11ZsZoneMemberID = Alias's t11ZsAliasName.\n\n           The StorageType of a row in this table is specified by\n           the instance of t11ZsServerDatabaseStorageType that is\n           INDEXed by the same values of fcmInstanceIndex,\n           fcmSwitchIndex, and t11ZsServerFabricIndex.")
t11ZsAliasIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 5, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsAliasIndex.setDescription('An index value which uniquely identifies this Zone\n           Alias within the Zone Set database of a particular\n           Fabric on a particular switch.')
t11ZsAliasName = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 5, 1, 2), T11ZoningName()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsAliasName.setDescription('The name of this Zone Alias.  The name of the Zone\n           Alias should be unique within a Fabric.\n\n           The Zone Alias can be renamed by setting this object\n           to a new value if and when it is not in a Zone, i.e.,\n           if and only if the current name is not the value of\n           any t11ZsZoneMemberID in the same Zone Set database.')
t11ZsAliasRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 5, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsAliasRowStatus.setDescription("The status of this conceptual row.\n\n           This object cannot be set to 'active' unless the\n           corresponding value of t11ZsAliasName is unique within\n           the Fabric's Zone Server database on this switch.")
t11ZsZoneMemberTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 6), )
if mibBuilder.loadTexts: t11ZsZoneMemberTable.setDescription("This table contains all members of a Zone/Zone Alias\n           and information about those members in the Zone Set\n           database of the Zone Servers on each Fabric in one or\n           more switches.\n\n           In Enhanced mode, changes to a database made via this\n           table are always made to the 'copy' database, but\n           values read from this table reflect the contents of\n           either the 'copy' database or the current (committed)\n           database as indicated by the corresponding value of\n           t11ZsServerReadFromDatabase.")
t11ZsZoneMemberEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 6, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsZoneMemberParentType"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsZoneMemberParentIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsZoneMemberIndex"))
if mibBuilder.loadTexts: t11ZsZoneMemberEntry.setDescription("Each entry represents the relationship between a\n           member and (one of) its 'parent(s)', i.e., a Zone\n           or Zone Alias to which the member belongs, within\n           a particular Fabric (identified by the value of\n           t11ZsServerFabricIndex) on a particular switch\n           (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).\n\n           A Zone member (other than an alias) is added to a\n           Zone by creating an entry in this table having:\n\n            - t11ZsZoneMemberParentType = 'zone',  and\n            - t11ZsZoneMemberParentIndex = Zone's t11ZsZoneIndex,\n            - t11ZsZoneMemberFormat != '05 - Alias Name',\n            - t11ZsZoneMemberID = Member's identifier.\n\n           An 'active' row in this table references rows in other\n           tables.  The agent must ensure that all such referenced\n           rows exist with a status of 'active', either by refusing to\n           create new active rows in this table, or by automatically\n           deleting any rows in this table that reference a deleted\n           row.\n\n           The StorageType of a row in this table is specified by\n           the instance of t11ZsServerDatabaseStorageType that is\n           INDEXed by the same values of fcmInstanceIndex,\n           fcmSwitchIndex, and t11ZsServerFabricIndex.")
t11ZsZoneMemberParentType = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 6, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("zone", 1), ("alias", 2),)))
if mibBuilder.loadTexts: t11ZsZoneMemberParentType.setDescription('This object determines whether this member belongs\n           to a Zone or Zone Alias.')
t11ZsZoneMemberParentIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 6, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsZoneMemberParentIndex.setDescription("This object contains the index value of the Zone or\n           Zone Alias to which this member belongs.\n\n           If the value of the corresponding instance of\n           t11ZsZoneMemberParentType is 'zone', then this object\n           will contain the value of the t11ZsZoneIndex object of\n           the Zone to which this member belongs.\n\n           If the value of the corresponding instance of\n           t11ZsZoneMemberParentType is 'alias', then this object\n           will contain the value of the t11ZsAliasIndex object\n           of the Zone Alias to which this member belongs.")
t11ZsZoneMemberIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 6, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsZoneMemberIndex.setDescription('An index value that uniquely identifies this Zone\n           Member amongst all Zone Members in the Zone Set\n           database of a particular Fabric on a particular switch.')
t11ZsZoneMemberFormat = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 6, 1, 4), T11ZsZoneMemberType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsZoneMemberFormat.setDescription("This object identifies the format of the\n           Zone/Zone Alias member's identifier contained in\n           t11ZsZoneMemberID.\n\n           This object cannot be modified while the corresponding\n           value of t11ZsZoneMemberRowStatus object is 'active'.")
t11ZsZoneMemberID = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 6, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsZoneMemberID.setDescription("This object contains the Member Identifier of the\n           Zone or Alias.  The interpretation of this object\n           depends on the value of the corresponding instance\n           of t11ZsZoneMemberFormat:\n\n             - if t11ZsZoneMemberFormat is 'N_Port_Name', then\n               this object contains an N_Port_Name.\n\n             - if t11ZsZoneMemberFormat is 'Domain_ID and physical\n               port', then this object contains a 4-octet value in\n               network byte order.  The first octet is zero,\n               the second octet contains the Domain_ID, and the\n               last 2 octets contain the physical port number.\n\n             - if t11ZsZoneMemberFormat is 'N_Port_ID', then this\n               object contains the 3-octet Nx_Port FC_ID.\n\n             - if t11ZsZoneMemberFormat is 'Alias Name', then\n               this object contains the value of t11ZsAliasName\n               for some Alias in the same Zone Set database.\n\n             - if t11ZsZoneMemberFormat is 'Node_Name', then\n               this object contains an 8-octet Node_Name.\n\n             - if t11ZsZoneMemberFormat is 'F_Port_Name', then\n               this object contains an 8-octet F_Port_Name.\n\n             - if t11ZsZoneMemberFormat is one of the 'Vendor\n               Specific' values, then this object contains a value\n               of 1 to 255 octets in a format defined by the relevant\n               vendor.\n\n           This object cannot be modified while the corresponding\n           value of t11ZsZoneMemberRowStatus object is 'active'.")
t11ZsZoneMemberRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 6, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsZoneMemberRowStatus.setDescription("The status of this conceptual row.\n\n\n\n\n           The corresponding instances of t11ZsZoneMemberID and\n           t11ZsZoneMemberFormat objects must be set before or\n           concurrently with setting this object to 'active'.")
t11ZsAttribBlockTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 7), )
if mibBuilder.loadTexts: t11ZsAttribBlockTable.setDescription("This table gives information on all the Zone\n           Attributes in the Zone Set database of the Zone\n           Servers on each Fabric in one or more switches.\n\n           In Enhanced mode, changes to a database made via this\n           table are always made to the 'copy' database, but\n           values read from this table reflect the contents of\n           either the 'copy' database or the current (committed)\n           database as indicated by the corresponding value of\n           t11ZsServerReadFromDatabase.")
t11ZsAttribBlockEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 7, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsAttribBlockIndex"))
if mibBuilder.loadTexts: t11ZsAttribBlockEntry.setDescription("Each entry contains information about a Zone Attribute\n           Block (of Zone Attributes) in the Zone Set database\n           of a particular Fabric (identified by the value of\n           t11ZsServerFabricIndex) on a particular switch\n           (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).\n\n           An 'active' row in this table references a row in the\n           t11ZsAttribBlockTable.  The agent must ensure that the\n           referenced rows exists with a status of 'active', either by\n           refusing to create new active rows in this table, or by\n           automatically deleting any rows in this table that\n           reference a deleted row.\n\n           The StorageType of a row in this table is specified by\n           the instance of t11ZsServerDatabaseStorageType that is\n           INDEXed by the same values of fcmInstanceIndex,\n\n\n\n           fcmSwitchIndex, and t11ZsServerFabricIndex.")
t11ZsAttribBlockIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 7, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsAttribBlockIndex.setDescription('An index value that uniquely identifies this Zone\n           Attribute within the Zone Set database of a particular\n           Fabric on a particular switch.')
t11ZsAttribBlockName = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 7, 1, 2), T11ZoningName()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsAttribBlockName.setDescription('The name of this Zone Attribute Block, which should\n           be unique within the Fabric.')
t11ZsAttribBlockRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 7, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsAttribBlockRowStatus.setDescription('The status of this conceptual row.')
t11ZsAttribTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 8), )
if mibBuilder.loadTexts: t11ZsAttribTable.setDescription("This table gives information on the Zone Attributes\n           within the Zone Attribute Blocks in the Zone Set\n           database of the Zone Servers on each Fabric in one\n           or more switches.\n\n           In Enhanced mode, changes to a database made via this\n           table are always made to the 'copy' database, but\n           values read from this table reflect the contents of\n           either the 'copy' database or the current (committed)\n           database as indicated by the corresponding value of\n           t11ZsServerReadFromDatabase.")
t11ZsAttribEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 8, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsAttribBlockIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsAttribIndex"))
if mibBuilder.loadTexts: t11ZsAttribEntry.setDescription('Each entry contains information about a Zone\n           Attribute in a Zone Attribute Block (identified by\n           t11ZsAttribBlockIndex) in the Zone Set database of\n           a particular Fabric (identified by the value of\n           t11ZsServerFabricIndex) on a particular switch\n           (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).\n\n           An entry in this table cannot be created prior to\n           its associated entry in the t11ZsAttribBlockTable.\n\n           The StorageType of a row in this table is specified by\n           the instance of t11ZsServerDatabaseStorageType that is\n           INDEXed by the same values of fcmInstanceIndex,\n           fcmSwitchIndex, and t11ZsServerFabricIndex.')
t11ZsAttribIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 8, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsAttribIndex.setDescription('An index value that uniquely identifies this\n           Zone Attribute within its Zone Attribute Block in\n           the Zone Set database of a particular Fabric on a\n           particular switch.')
t11ZsAttribType = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 8, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsAttribType.setDescription('The type of attribute:\n\n                0001       - Protocol\n                0002       - Broadcast Zone\n                0003       - Hard Zone\n                00E0 (hex) - Vendor Specific.')
t11ZsAttribValue = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 8, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(4,252))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsAttribValue.setDescription('The value of the attribute, formatted as specified\n           in FC-GS-5 for the type given by the corresponding\n           instance of t11ZsAttribType.\n\n           Note that FC-GS-5 requires that the length of this\n           value is a multiple of 4 bytes.')
t11ZsAttribRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 8, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11ZsAttribRowStatus.setDescription('The status of this conceptual row.')
t11ZsActivateTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 9), )
if mibBuilder.loadTexts: t11ZsActivateTable.setDescription('This table provides a mechanism to allow a Zone Set\n           to be activated on a Fabric.')
t11ZsActivateEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 9, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"))
if mibBuilder.loadTexts: t11ZsActivateEntry.setDescription('Each entry reflects the state of the activation of a\n           Zone Set by a particular switch (identified by values\n           of fcmInstanceIndex and fcmSwitchIndex) on a particular\n           Fabric (identified by the value of\n           t11ZsServerFabricIndex).')
t11ZsActivateRequest = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 9, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsActivateRequest.setDescription('Setting this object to a value is a request for a\n           Zone Set to be activated on the Fabric that is\n           represented by this row.  The Zone Set to be\n           activated is the one for which t11ZsSetIndex has\n           the same value.\n\n           If a Zone Set is already active on a Fabric when a\n           request is made to activate a different one on that\n           Fabric, then the existing Zone Set is automatically\n           deactivated and the specified Zone Set is activated\n           in its place.\n\n           The value of this object when read is always 0.')
t11ZsActivateDeactivate = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 9, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("deactivate", 1), ("noop", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsActivateDeactivate.setDescription("Setting this object to 'deactivate' is a request\n           to deactivate the currently active Zone Set on\n           a Fabric.\n\n           Note that the deactivation of the active Zone Set\n           allows all ports to communicate or no ports to\n           communicate, depending on the current Default Zone\n           behavior.\n\n           No action is taken if this object is set to 'noop'.\n           When read, the value of this object is always 'noop'.")
t11ZsActivateResult = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 9, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("activateSuccess", 1), ("activateFailure", 2), ("deactivateSuccess", 3), ("deactivateFailure", 4), ("inProgress", 5), ("none", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActivateResult.setDescription("This object indicates the outcome of the most recent\n           activation/deactivation using this entry.\n\n           When the value of this object is 'inProgress', the\n           values of the corresponding instances of\n           t11ZsActivateRequest and t11ZsActivateDeactivate\n           cannot be modified.\n\n           The value 'none' indicates activation/deactivation\n           has not been attempted since the last restart of\n           the management system.")
t11ZsActivateFailCause = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 9, 1, 4), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,64))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActivateFailCause.setDescription("A textual message indicating the reason for the\n           most recent failure of a Zone Set activation or\n           deactivation, or the zero-length string if no\n           information is available (e.g., because the\n           corresponding instance of t11ZsActivateResult\n           has the value 'none').\n\n           When the corresponding instance of\n           t11ZsActivateResult is either 'activateFailure'\n           or 'deactivateFailure', the value of this object\n           indicates the reason for that failure.")
t11ZsActivateFailDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 9, 1, 5), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActivateFailDomainId.setDescription('If the failure cause (as indicated by\n           t11ZsSetFailCause) was specific to a particular\n           device, this object contains the Domain_ID of that\n           device.  Otherwise, this object contains zero.')
t11ZsActiveTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 10), )
if mibBuilder.loadTexts: t11ZsActiveTable.setDescription('A table containing information on the currently\n           enforced/active Zone Set on each Fabric.\n           An active Zone Set cannot be modified.\n           This table will be empty when no Zone Set is\n           activated.')
t11ZsActiveEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 10, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"))
if mibBuilder.loadTexts: t11ZsActiveEntry.setDescription('Each entry represents an active Zone Set of a\n           particular Fabric (identified by the value of\n           t11ZsServerFabricIndex), according to a particular\n           switch (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).')
t11ZsActiveZoneSetName = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 10, 1, 1), T11ZoningName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveZoneSetName.setDescription('The name of this Zone Set on this Fabric.')
t11ZsActiveActivateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 10, 1, 2), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveActivateTime.setDescription('The value of sysUpTime at which this entry was most\n           recently activated.  If this row was activated prior to\n           the last re-initialization of the local network management\n           system, then this object will contain a zero value.')
t11ZsActiveZoneTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 11), )
if mibBuilder.loadTexts: t11ZsActiveZoneTable.setDescription('This table contains all the Zones that are present in\n           the active Zone Sets on all Fabrics.')
t11ZsActiveZoneEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 11, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneIndex"))
if mibBuilder.loadTexts: t11ZsActiveZoneEntry.setDescription('Each entry represents a Zone in the active Zone Set\n           of a particular Fabric (identified by the value of\n           t11ZsServerFabricIndex), according to a particular\n           switch (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).')
t11ZsActiveZoneIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 11, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsActiveZoneIndex.setDescription('An index value that uniquely identifies this Zone\n           within the active Zone Set on a particular Fabric.')
t11ZsActiveZoneName = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 11, 1, 2), T11ZoningName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveZoneName.setDescription('The name of this Zone.')
t11ZsActiveZoneBroadcastZoning = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 11, 1, 3), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveZoneBroadcastZoning.setDescription('This object indicates whether broadcast Zoning is\n           enabled on this Zone.  If broadcast Zoning is enabled,\n           then broadcast frames generated by a member in this\n           Zone will be restricted to members in this Zone.\n\n           This object is only instantiated in Enhanced mode.')
t11ZsActiveZoneHardZoning = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 11, 1, 4), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveZoneHardZoning.setDescription('This object indicates whether hard Zoning is\n           enabled on this Zone.\n\n           This object is only instantiated in Enhanced mode.')
t11ZsActiveZoneMemberTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 12), )
if mibBuilder.loadTexts: t11ZsActiveZoneMemberTable.setDescription('This table contains all members of all Zones\n           within the active Zone Set on any Fabric.')
t11ZsActiveZoneMemberEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 12, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneMemberIndex"))
if mibBuilder.loadTexts: t11ZsActiveZoneMemberEntry.setDescription('Each entry represents a member of a Zone in the active\n           Zone Set of a particular Fabric (identified by the value\n           t11ZsServerFabricIndex), according to a particular\n           switch (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).')
t11ZsActiveZoneMemberIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 12, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsActiveZoneMemberIndex.setDescription('An index value that uniquely identifies this\n           member amongst the members of a particular Zone\n           in the active Zone Set on a particular Fabric.')
t11ZsActiveZoneMemberFormat = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 12, 1, 2), T11ZsZoneMemberType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveZoneMemberFormat.setDescription('This object identifies the identifier format of the\n           corresponding instance of t11ZsActiveZoneMemberID.')
t11ZsActiveZoneMemberID = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 12, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveZoneMemberID.setDescription('This value of this object identifies the member\n           using the format specified in the corresponding\n           instance of t11ZsActiveZoneMemberFormat.')
t11ZsActiveAttribTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 13), )
if mibBuilder.loadTexts: t11ZsActiveAttribTable.setDescription('This table contains information about some of the\n           Attributes of the Zones within the active Zone Set\n           on each Fabric.\n\n           This table contains all the types of attributes\n           that might apply zero, one, or more times to a Zone.\n           Attributes that apply once and only to a Zone are\n           specified in the t11ZsActiveZoneTable.\n\n           This table will always be empty in Basic mode.\n           It will also be empty if there are no Zones in\n           any active Zone Set having any of the applicable\n           types of attributes.')
t11ZsActiveAttribEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 13, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsActiveAttribIndex"))
if mibBuilder.loadTexts: t11ZsActiveAttribEntry.setDescription('Each entry contains an Attribute of a particular\n           Zone in the active Zone Set of a particular Fabric\n           (identified by the value of t11ZsServerFabricIndex),\n           according to a particular switch (identified by\n           values of fcmInstanceIndex and fcmSwitchIndex).')
t11ZsActiveAttribIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 13, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11ZsActiveAttribIndex.setDescription('An index value that uniquely identifies this\n           attribute amongst the other attributes for a\n           particular Zone in the active Zone Set on a\n           particular Fabric.')
t11ZsActiveAttribType = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 13, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveAttribType.setDescription('The type of attribute:\n\n                0001       - Protocol\n                00E0 (hex) - Vendor Specific\n\n           Note that type 2 (Hard) and type 3 (Broadcast)\n           do not need to be represented here, because they\n           are represented by t11ZsActiveZoneBroadcastZoning and\n           t11ZsActiveZoneHardZoning.')
t11ZsActiveAttribValue = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 13, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,252))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsActiveAttribValue.setDescription('The value of the attribute, formatted according to\n           its type as indicated by the corresponding instance\n           of t11ZsActiveAttribType.\n\n           As specified in FC-GS-5, the length of an attribute\n           value is at least 4 bytes, and if necessary, the value\n           is appended with zero bytes so that the length is a\n           multiple of 4.  For a Vendor-Specific attribute\n           value, the first 8 bytes contain the T10 Vendor ID\n           as described in FC-GS-5.')
t11ZsStatsTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 2, 1), )
if mibBuilder.loadTexts: t11ZsStatsTable.setDescription('A table of statistics maintained by Zone Servers.')
t11ZsStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"))
if mibBuilder.loadTexts: t11ZsStatsEntry.setDescription('A set of statistics for a Zone Server on a\n           particular Fabric (identified by the value of\n           t11ZsServerFabricIndex) on a particular switch\n           (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).')
t11ZsOutMergeRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsOutMergeRequests.setDescription('The number of Merge Request Frames sent by this Zone\n           Server to other Zone Servers in the same Fabric.\n\n           This counter has no discontinuities other than those\n\n\n\n           that all Counter32s have when sysUpTime=0.')
t11ZsInMergeAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsInMergeAccepts.setDescription('The number of Merge Accept Frames received by this Zone\n           Server from other Zone Servers in the same Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsInMergeRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsInMergeRequests.setDescription('The number of Merge Request Frames received by this Zone\n           Server from other Zone Servers in the same Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsOutMergeAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsOutMergeAccepts.setDescription('The number of Merge Accept Frames sent by this Zone\n           Server to other Zone Servers in the same Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsOutChangeRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsOutChangeRequests.setDescription('The number of change requests sent (via the Fabric\n           Management Session Protocol) by this Zone Server to\n           other Zone Servers in the same Fabric.\n\n\n\n\n           This includes Acquire Change Authorization requests, Stage\n           Fabric Config Update requests, Update Fabric Config requests\n           and Release Change Authorization requests.  It also includes\n           the corresponding types of requests defined by the Enhanced\n           Commit Service.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsInChangeAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsInChangeAccepts.setDescription('The number of SW_ACC messages received from other Zone\n           Servers in the same Fabric (according to the Fabric\n           Management Session Protocol) in response to change\n           requests by this Zone Server.\n\n           This includes SW_ACC messages received in response to\n           Acquire Change Authorization requests, to Stage Fabric\n           Config Update requests, to Update Fabric Config requests,\n           and to Release Change Authorization requests.  It also\n           includes responses to the corresponding types of requests\n           defined for the Enhanced Commit Service.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsInChangeRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsInChangeRequests.setDescription('The number of change requests received (via the Fabric\n           Management Session Protocol) by this Zone Server from\n           other Zone Servers in the same Fabric.\n\n           This includes Acquire Change Authorization requests, Stage\n           Fabric Config Update requests, Update Fabric Config requests\n\n\n\n           and Release Change Authorization requests.  It also includes\n           the corresponding types of requests defined by the Enhanced\n           Commit Service.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsOutChangeAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsOutChangeAccepts.setDescription('The number of SW_ACC messages sent by this Zone Server\n           (according to the Fabric Management Session Protocol) in\n           response to change requests from other Zone Servers in\n           the same Fabric.\n\n           This includes SW_ACC messages sent in response to\n           Acquire Change Authorization requests, to Stage Fabric\n           Config Update requests, to Update Fabric Config requests\n           and to Release Change Authorization requests.  It also\n           includes responses to the corresponding types of requests\n           defined for the Enhanced Commit Service.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsInZsRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsInZsRequests.setDescription('The number of Zone Server requests received by this\n           Zone Server on this Fabric, both those received in\n           Basic mode and in Enhanced mode.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsOutZsRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 2, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsOutZsRejects.setDescription('The number of Zone Server requests rejected by this\n           Zone Server on this Fabric, both those rejected in\n           Basic mode and in Enhanced mode.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11ZsNotifyControlTable = MibTable((1, 3, 6, 1, 2, 1, 160, 1, 1, 14), )
if mibBuilder.loadTexts: t11ZsNotifyControlTable.setDescription('A table of control information for notifications\n           generated due to Zone Server events.')
t11ZsNotifyControlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ZONE-SERVER-MIB", "t11ZsServerFabricIndex"))
if mibBuilder.loadTexts: t11ZsNotifyControlEntry.setDescription('Each entry contains notification control information\n           specific to a Zone Server for a particular Fabric\n           (identified by the value of t11ZsServerFabricIndex)\n           on a particular switch (identified by values of\n           fcmInstanceIndex and fcmSwitchIndex).\n\n           The persistence across reboots of writable values in\n           a row of this table is specified by the instance of\n           t11ZsServerDatabaseStorageType that is INDEXed by\n           the same values of fcmInstanceIndex, fcmSwitchIndex,\n           and t11ZsServerFabricIndex.')
t11ZsNotifyRequestRejectEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 1), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsNotifyRequestRejectEnable.setDescription('This object specifies whether t11ZsRequestRejectNotify\n           notifications should be generated by the Zone Server\n           for this Fabric.')
t11ZsNotifyMergeFailureEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 2), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsNotifyMergeFailureEnable.setDescription('This object specifies whether t11ZsMergeFailureNotify\n           notifications should be generated by the Zone Server\n           for this Fabric.')
t11ZsNotifyMergeSuccessEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 3), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsNotifyMergeSuccessEnable.setDescription('This object specifies whether t11ZsMergeSuccessNotify\n           notifications should be generated by the Zone Server\n           for this Fabric.')
t11ZsNotifyDefZoneChangeEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 4), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsNotifyDefZoneChangeEnable.setDescription('This object specifies whether t11ZsDefZoneChangeNotify\n           notifications should be generated by the Zone Server\n\n\n\n           for this Fabric.')
t11ZsNotifyActivateEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 5), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11ZsNotifyActivateEnable.setDescription('This object specifies whether t11ZsActivateNotify\n           notifications should be generated by the Zone Server\n           for this Fabric.')
t11ZsRejectCtCommandString = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsRejectCtCommandString.setDescription("The binary content of the Zone Server request,\n           formatted as an octet string (in network byte order)\n           containing the Common Transport Information Unit\n           (CT_IU), as described in Table 2 of FC-GS-5 (including\n           the preamble), which was most recently rejected by the\n           Fabric Configuration Server for this Fabric.\n\n           This object contains the zero-length string\n           if and when the CT-IU's content is unavailable.\n\n           When the length of this object is 255 octets, it\n           contains the first 255 octets of the CT-IU (in\n           network byte order).")
t11ZsRejectRequestSource = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 7), FcNameIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsRejectRequestSource.setDescription('The WWN that was the source of the CT_IU\n           contained in the corresponding instance of\n           t11ZsRejectCtCommandString.')
t11ZsRejectReasonCode = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 8), T11NsGs4RejectReasonCode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsRejectReasonCode.setDescription('The reason code corresponding to the most recent\n           rejection of a request by the Zone Server for\n           this Fabric.')
t11ZsRejectReasonCodeExp = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 9), T11ZsRejectReasonExplanation()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsRejectReasonCodeExp.setDescription("When the value of t11ZsRejectReasonCode is\n           'Unable to perform command request', this\n           object contains the corresponding reason code\n           explanation.")
t11ZsRejectReasonVendorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 160, 1, 1, 14, 1, 10), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1)).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11ZsRejectReasonVendorCode.setDescription("When the value of t11ZsRejectReasonCode is\n           'Vendor Specific Error', this object contains\n           the corresponding vendor-specific reason code.")
t11ZsFabricIndex = MibScalar((1, 3, 6, 1, 2, 1, 160, 1, 1, 15), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4096))).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: t11ZsFabricIndex.setDescription('This object contains either a value of\n           T11FabricIndex to identify the Fabric on which\n           some occurrence has caused a notification to be\n           generated, or it has the value 4096 to indicate\n           all applicable Fabrics.')
t11ZsRequestRejectNotify = NotificationType((1, 3, 6, 1, 2, 1, 160, 0, 1)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11FamLocalSwitchWwn"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectRequestSource"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectCtCommandString"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectReasonCode"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectReasonCodeExp"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectReasonVendorCode"),))
if mibBuilder.loadTexts: t11ZsRequestRejectNotify.setDescription('This notification is generated whenever a Zone Server\n           (indicated by the value of t11FamLocalSwitchWwn) rejects\n           a request.\n\n           The value of t11ZsRejectCtCommandString indicates the\n           rejected request, and the values of t11ZsRejectReasonCode,\n           t11ZsRejectReasonCodeExp and t11ZsRejectReasonVendorCode\n           indicate the reason for the rejection.  The value of\n           t11ZsRequestClient indicates the source of the request.')
t11ZsMergeFailureNotify = NotificationType((1, 3, 6, 1, 2, 1, 160, 0, 2)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "ifIndex"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsFabricIndex"),))
if mibBuilder.loadTexts: t11ZsMergeFailureNotify.setDescription('This notification indicates that a Zone merge\n           failure has occurred on the Fabric indicated by the\n           value of t11ZsFabricIndex, on the interface\n           indicated by the value of ifIndex.\n\n           If multiple Virtual Fabrics are configured on an\n           interface, and all have a Zone merge failure\n           at the same time, then just one notification is\n           generated and t11ZsFabricIndex has the value 4096.')
t11ZsMergeSuccessNotify = NotificationType((1, 3, 6, 1, 2, 1, 160, 0, 3)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "ifIndex"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsFabricIndex"),))
if mibBuilder.loadTexts: t11ZsMergeSuccessNotify.setDescription('This notification indicates that a successful Zone\n           merge has occurred on the Fabric indicated by the\n           value of t11ZsFabricIndex, on the interface\n           indicated by the value of ifIndex.\n\n           If multiple Virtual Fabrics are configured on an\n           interface, and all have a successful Zone Merge\n\n\n\n           at the same time, then just one notification is\n           generated and t11ZsFabricIndex has the value 4096.')
t11ZsDefZoneChangeNotify = NotificationType((1, 3, 6, 1, 2, 1, 160, 0, 4)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsServerDefaultZoneSetting"),))
if mibBuilder.loadTexts: t11ZsDefZoneChangeNotify.setDescription('This notification indicates that the\n           value of a Default Zone Setting has changed.\n           The value of t11ZsServerDefaultZoneSetting\n           contains the value after the change.')
t11ZsActivateNotify = NotificationType((1, 3, 6, 1, 2, 1, 160, 0, 5)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11FamLocalSwitchWwn"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateResult"),))
if mibBuilder.loadTexts: t11ZsActivateNotify.setDescription('This notification is generated whenever a switch\n           (indicated by the value of t11FamLocalSwitchWwn)\n           activates/deactivates a Zone Set on a Fabric.\n           The t11ZsActivateResult object denotes the outcome\n           of the activation/deactivation.')
t11ZsMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 160, 2, 1))
t11ZsMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 160, 2, 2))
t11ZsMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 160, 2, 1, 1)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsBasicGroup"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsNotificationControlGroup"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsNotificationGroup"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsEnhancedModeGroup"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateGroup"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsStatisticsGroup"),))
if mibBuilder.loadTexts: t11ZsMIBCompliance.setDescription('The compliance statement for entities that\n           implement the Zone Server.')
t11ZsBasicGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 160, 2, 2, 1)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsServerCapabilityObject"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerDatabaseStorageType"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerDistribute"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerResult"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerReasonCode"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerReasonCodeExp"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerReasonVendorCode"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerLastChange"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerHardZoning"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerReadFromDatabase"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerOperationMode"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsSetName"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsSetRowStatus"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsZoneName"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsZoneAttribBlock"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsZoneRowStatus"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsSetZoneRowStatus"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsZoneMemberFormat"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsZoneMemberID"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsZoneMemberRowStatus"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneSetName"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveActivateTime"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneName"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneMemberFormat"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneMemberID"),))
if mibBuilder.loadTexts: t11ZsBasicGroup.setDescription('A collection of objects for displaying and updating\n           the Zone configuration of a Zone Server capable of\n           operating in Basic mode.')
t11ZsEnhancedModeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 160, 2, 2, 2)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsServerCommit"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerChangeModeResult"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerDefaultZoneSetting"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerMergeControlSetting"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsServerDefZoneBroadcast"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsAliasName"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsAliasRowStatus"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsAttribBlockName"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsAttribBlockRowStatus"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsAttribType"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsAttribValue"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsAttribRowStatus"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneBroadcastZoning"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveZoneHardZoning"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveAttribType"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActiveAttribValue"),))
if mibBuilder.loadTexts: t11ZsEnhancedModeGroup.setDescription('A collection of additional objects for displaying\n           and updating the Zone configuration of a Zone Server\n           capable of operating in Enhanced mode.')
t11ZsStatisticsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 160, 2, 2, 3)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsOutMergeRequests"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsInMergeAccepts"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsInMergeRequests"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsOutMergeAccepts"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsOutChangeRequests"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsInChangeAccepts"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsInChangeRequests"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsOutChangeAccepts"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsInZsRequests"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsOutZsRejects"),))
if mibBuilder.loadTexts: t11ZsStatisticsGroup.setDescription('A collection of objects for collecting Zone Server\n            statistics information.')
t11ZsNotificationControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 160, 2, 2, 4)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsNotifyRequestRejectEnable"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsNotifyMergeFailureEnable"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsNotifyMergeSuccessEnable"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsNotifyDefZoneChangeEnable"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsNotifyActivateEnable"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectCtCommandString"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectRequestSource"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectReasonCode"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectReasonCodeExp"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsRejectReasonVendorCode"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsFabricIndex"),))
if mibBuilder.loadTexts: t11ZsNotificationControlGroup.setDescription('A collection of notification control and\n           notification information objects for monitoring\n           Zone Server request rejection and Zone merge\n           failures.')
t11ZsActivateGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 160, 2, 2, 5)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateRequest"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateDeactivate"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateResult"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateFailCause"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateFailDomainId"),))
if mibBuilder.loadTexts: t11ZsActivateGroup.setDescription('A collection of objects that allow a Zone Set to\n           be activated via SNMP SetRequests and provide the\n           status and result of such an activation.')
t11ZsNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 160, 2, 2, 6)).setObjects(*(("T11-FC-ZONE-SERVER-MIB", "t11ZsRequestRejectNotify"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsMergeFailureNotify"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsMergeSuccessNotify"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsDefZoneChangeNotify"), ("T11-FC-ZONE-SERVER-MIB", "t11ZsActivateNotify"),))
if mibBuilder.loadTexts: t11ZsNotificationGroup.setDescription('A collection of notification(s) for monitoring\n           Zone Server request rejection, Zone merge\n           failures and successes, and Default Zoning\n           behavioral changes.')
mibBuilder.exportSymbols("T11-FC-ZONE-SERVER-MIB", t11ZsServerEntry=t11ZsServerEntry, t11ZsServerDistribute=t11ZsServerDistribute, t11ZsAttribBlockName=t11ZsAttribBlockName, t11ZsInChangeAccepts=t11ZsInChangeAccepts, t11ZsFabricIndex=t11ZsFabricIndex, t11ZsServerOperationMode=t11ZsServerOperationMode, t11ZsZoneRowStatus=t11ZsZoneRowStatus, t11ZsAttribValue=t11ZsAttribValue, t11ZsSetRowStatus=t11ZsSetRowStatus, t11ZsActivateGroup=t11ZsActivateGroup, t11ZsActiveAttribIndex=t11ZsActiveAttribIndex, T11ZsZoneMemberType=T11ZsZoneMemberType, t11ZsAttribIndex=t11ZsAttribIndex, t11ZsOutMergeRequests=t11ZsOutMergeRequests, t11ZsServerTable=t11ZsServerTable, t11ZsZoneMemberFormat=t11ZsZoneMemberFormat, t11ZsAttribRowStatus=t11ZsAttribRowStatus, t11ZsInZsRequests=t11ZsInZsRequests, t11ZsStatistics=t11ZsStatistics, t11ZsActiveZoneHardZoning=t11ZsActiveZoneHardZoning, t11ZsMergeSuccessNotify=t11ZsMergeSuccessNotify, t11ZsActivateNotify=t11ZsActivateNotify, t11ZsActiveZoneBroadcastZoning=t11ZsActiveZoneBroadcastZoning, t11ZsActivateFailDomainId=t11ZsActivateFailDomainId, t11ZsRejectReasonCode=t11ZsRejectReasonCode, t11ZsActiveTable=t11ZsActiveTable, t11ZsAliasRowStatus=t11ZsAliasRowStatus, t11ZsSetEntry=t11ZsSetEntry, t11ZsAliasEntry=t11ZsAliasEntry, t11ZsMIBCompliance=t11ZsMIBCompliance, t11ZsMIBConformance=t11ZsMIBConformance, t11ZsActiveZoneMemberEntry=t11ZsActiveZoneMemberEntry, t11ZsAttribBlockEntry=t11ZsAttribBlockEntry, t11ZsAttribType=t11ZsAttribType, t11ZsZoneEntry=t11ZsZoneEntry, t11ZsZoneMemberParentType=t11ZsZoneMemberParentType, t11ZsActivateResult=t11ZsActivateResult, t11ZsActiveAttribEntry=t11ZsActiveAttribEntry, t11ZsAliasName=t11ZsAliasName, t11ZsOutMergeAccepts=t11ZsOutMergeAccepts, t11ZsServerReasonCode=t11ZsServerReasonCode, t11ZsSetZoneRowStatus=t11ZsSetZoneRowStatus, t11ZsDefZoneChangeNotify=t11ZsDefZoneChangeNotify, t11ZsSetIndex=t11ZsSetIndex, t11ZsServerCommit=t11ZsServerCommit, t11ZoneServerMIB=t11ZoneServerMIB, t11ZsZoneAttribBlock=t11ZsZoneAttribBlock, t11ZsSetZoneEntry=t11ZsSetZoneEntry, t11ZsActivateRequest=t11ZsActivateRequest, t11ZsActiveActivateTime=t11ZsActiveActivateTime, t11ZsServerMergeControlSetting=t11ZsServerMergeControlSetting, t11ZsServerChangeModeResult=t11ZsServerChangeModeResult, t11ZsZoneIndex=t11ZsZoneIndex, t11ZsAttribBlockTable=t11ZsAttribBlockTable, t11ZsZoneMemberIndex=t11ZsZoneMemberIndex, t11ZsActiveZoneTable=t11ZsActiveZoneTable, t11ZsRejectReasonCodeExp=t11ZsRejectReasonCodeExp, t11ZsServerReasonCodeExp=t11ZsServerReasonCodeExp, t11ZsZoneMemberRowStatus=t11ZsZoneMemberRowStatus, t11ZsMIBGroups=t11ZsMIBGroups, t11ZsZoneTable=t11ZsZoneTable, t11ZsServerDatabaseStorageType=t11ZsServerDatabaseStorageType, t11ZsRejectRequestSource=t11ZsRejectRequestSource, t11ZsServerFabricIndex=t11ZsServerFabricIndex, t11ZsServerReasonVendorCode=t11ZsServerReasonVendorCode, t11ZsServerResult=t11ZsServerResult, t11ZsServerReadFromDatabase=t11ZsServerReadFromDatabase, t11ZsInMergeAccepts=t11ZsInMergeAccepts, t11ZsMergeFailureNotify=t11ZsMergeFailureNotify, t11ZsRequestRejectNotify=t11ZsRequestRejectNotify, t11ZsInChangeRequests=t11ZsInChangeRequests, t11ZsActiveEntry=t11ZsActiveEntry, t11ZsStatsEntry=t11ZsStatsEntry, PYSNMP_MODULE_ID=t11ZoneServerMIB, t11ZsActiveZoneEntry=t11ZsActiveZoneEntry, t11ZsZoneMemberTable=t11ZsZoneMemberTable, t11ZsOutChangeRequests=t11ZsOutChangeRequests, t11ZsAttribBlockRowStatus=t11ZsAttribBlockRowStatus, t11ZsActiveZoneIndex=t11ZsActiveZoneIndex, t11ZsSetName=t11ZsSetName, t11ZsNotifyActivateEnable=t11ZsNotifyActivateEnable, t11ZsAttribEntry=t11ZsAttribEntry, t11ZsRejectReasonVendorCode=t11ZsRejectReasonVendorCode, t11ZsSetTable=t11ZsSetTable, t11ZsRejectCtCommandString=t11ZsRejectCtCommandString, t11ZsAttribTable=t11ZsAttribTable, t11ZsNotifyRequestRejectEnable=t11ZsNotifyRequestRejectEnable, t11ZsAliasIndex=t11ZsAliasIndex, T11ZsRejectReasonExplanation=T11ZsRejectReasonExplanation, t11ZsServerDefaultZoneSetting=t11ZsServerDefaultZoneSetting, t11ZsActivateFailCause=t11ZsActivateFailCause, t11ZsBasicGroup=t11ZsBasicGroup, t11ZsZoneName=t11ZsZoneName, t11ZsActiveAttribValue=t11ZsActiveAttribValue, t11ZsActiveAttribTable=t11ZsActiveAttribTable, t11ZsAliasTable=t11ZsAliasTable, t11ZsOutChangeAccepts=t11ZsOutChangeAccepts, T11ZoningName=T11ZoningName, t11ZsNotifyMergeSuccessEnable=t11ZsNotifyMergeSuccessEnable, t11ZsActivateEntry=t11ZsActivateEntry, t11ZsActiveZoneMemberIndex=t11ZsActiveZoneMemberIndex, t11ZsNotificationGroup=t11ZsNotificationGroup, t11ZsEnhancedModeGroup=t11ZsEnhancedModeGroup, t11ZsActiveZoneMemberID=t11ZsActiveZoneMemberID, t11ZsActiveZoneName=t11ZsActiveZoneName, t11ZsMIBCompliances=t11ZsMIBCompliances, t11ZsNotifyMergeFailureEnable=t11ZsNotifyMergeFailureEnable, t11ZsZoneMemberID=t11ZsZoneMemberID, t11ZsActivateTable=t11ZsActivateTable, t11ZsServerHardZoning=t11ZsServerHardZoning, t11ZsZoneMemberParentIndex=t11ZsZoneMemberParentIndex, t11ZsNotifyControlTable=t11ZsNotifyControlTable, t11ZsSetZoneTable=t11ZsSetZoneTable, t11ZsMIBObjects=t11ZsMIBObjects, t11ZsActiveZoneMemberTable=t11ZsActiveZoneMemberTable, t11ZsInMergeRequests=t11ZsInMergeRequests, t11ZsActiveAttribType=t11ZsActiveAttribType, t11ZsZoneMemberEntry=t11ZsZoneMemberEntry, t11ZsNotifyDefZoneChangeEnable=t11ZsNotifyDefZoneChangeEnable, t11ZsNotificationControlGroup=t11ZsNotificationControlGroup, t11ZsStatsTable=t11ZsStatsTable, t11ZsServerLastChange=t11ZsServerLastChange, t11ZsServerCapabilityObject=t11ZsServerCapabilityObject, t11ZsStatisticsGroup=t11ZsStatisticsGroup, t11ZsActiveZoneMemberFormat=t11ZsActiveZoneMemberFormat, t11ZsMIBNotifications=t11ZsMIBNotifications, t11ZsNotifyControlEntry=t11ZsNotifyControlEntry, t11ZsActivateDeactivate=t11ZsActivateDeactivate, t11ZsServerDefZoneBroadcast=t11ZsServerDefZoneBroadcast, t11ZsOutZsRejects=t11ZsOutZsRejects, t11ZsConfiguration=t11ZsConfiguration, t11ZsAttribBlockIndex=t11ZsAttribBlockIndex, t11ZsActiveZoneSetName=t11ZsActiveZoneSetName)
